@@ -3,7 +3,9 @@
 #' A missing POSIXct object
 #' @family NA
 #' @export
-NA_POSIXct_ <- set_attr(set_class(NA_real_, c("POSIXct", "POSIXt")), "tzone", "UTC")
+NA_POSIXct_ <- set_attr(
+  set_class(NA_real_, c("POSIXct", "POSIXt")), "tzone", "UTC"
+)
 
 #' Missing Date
 #'
@@ -15,4 +17,6 @@ NA_Date_ <- set_class(NA_real_, "Date")
 #'
 #' A missing hms object
 #' @export
-NA_hms_ <- set_class(as.difftime(NA_real_, units = "secs"), c("hms", "difftime"))
+NA_hms_ <- set_class(
+  as.difftime(NA_real_, units = "secs"), c("hms", "difftime")
+)
